================
pytorch-nn-tools
================


.. image:: https://img.shields.io/pypi/v/pytorch-nn-tools.svg
        :target: https://pypi.python.org/pypi/pytorch-nn-tools

.. image:: https://img.shields.io/travis/serge-m/pytorch-nn-tools.svg
        :target: https://travis-ci.com/serge-m/pytorch-nn-tools

.. image:: https://readthedocs.org/projects/pytorch-nn-tools/badge/?version=latest
        :target: https://pytorch-nn-tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Tools for NN creation with Pytorch


* Free software: MIT license
* Documentation: https://pytorch-nn-tools.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
